Inventariseren

# Groenvoorzieningwerk en werken in natuurterrein

The temperature of all fridges is checked daily Yes No Not applicable

The temperature in a fridge is critical to storing food. If the temperature is too high or fluctuates too much food can start rotting quickly.

#### More information

- The sector organisation has a manual on fridge maintenance. Lorem ipsum dolor sit amet consectuer.
- A link to a popular brand of fridges

#### Legal and policy references

The requirements for fridges are defined in section 13.1 section a of the health code.

Please leave any comments you may have on the question above in this field

1. Voorbereiden
2. Inventariseren
   1. 2.1 Werksoorten
      1. 2.1.1 Handgedragen machinewerk
      2. 2.1.2 Zitgebonden machinewerk zelfrijdende bosbouwmachines
      3. 2.1.3 Groenvoorzieningwerk en werken in natuurterrein
         1. Long and descriptive name of step
         2. Long and descriptive name of step
         3. Long and descriptive name of step
         4. Long and descriptive name of step
         5. Long and descriptive name of step
         6. Long and descriptive name of step
         7. Long and descriptive name of step
         8. Long and descriptive name of step
         9. Long and descriptive name of step
         10. Long and descriptive name of step
         11. Long and descriptive name of step
         12. Long and descriptive name of step
         13. Long and descriptive name of step
         14. Long and descriptive name of step
      4. 2.1.4 Onderhoud, werkplaats en opslag.
      5. 2.1.5 Maaiboten
      6. 2.1.6 Surveillance, inventarisatie en rondleidingen
      7. 2.1.7 Werken bij hoogspanningsleidingen
      8. 2.1.8 Kantoorwerk
   2. Bijzondere omstandigheden
3. Evalueren
4. Plan van aanpak
5. Rapporten

Link to sector organisation | Disclaimer | Design by Cornae